==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-file-watch/src/test/java/org/apache/camel/component/file/watch/FileWatchComponentNegativeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file.watch;

import java.nio.file.Paths;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.fail;

public class FileWatchComponentNegativeTest extends FileWatchComponentTestBase {

    @Test
    public void testNonExistentDirectory() throws Exception {
        String nonExistentDirectory = Paths.get(testPath(), "nonExistentDirectory").toString();
        try {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("file-watch://" + nonExistentDirectory + "?autoCreate=false").to("mock:watchAll");
                }
            });
            fail("Should throw exception");
        } catch (Exception ignored) {
        }

        context.addRoutes(new RouteBuilder() {
            @Override
            public void configure() {
                from("file-watch://" + nonExistentDirectory + "?autoCreate=true").to("mock:watchAll");
            }
        });

    }

}

==> apache-camel-4.18.0-src.zip: apache-camel-4.18.0/components/camel-file-watch/src/test/java/org/apache/camel/component/file/watch/FileWatchComponentNegativeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.file.watch;

import java.nio.file.Paths;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertThrows;

public class FileWatchComponentNegativeTest extends FileWatchComponentTestBase {

    @Test
    public void testNonExistentDirectory() throws Exception {
        String nonExistentDirectory = Paths.get(testPath(), "nonExistentDirectory").toString();
        assertThrows(Exception.class, () -> {
            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("file-watch://" + nonExistentDirectory + "?autoCreate=false").to("mock:watchAll");
                }
            });
        });

        context.addRoutes(new RouteBuilder() {
            @Override
            public void configure() {
                from("file-watch://" + nonExistentDirectory + "?autoCreate=true").to("mock:watchAll");
            }
        });

    }

}
